pub enum AirflowClusterImagePullPolicy {
IfNotPresent,
Always,
Never,
}Expand description
Specify which image to use, the easiest way is to only configure the productVersion.
You can also configure a custom image registry to pull from, as well as completely custom
images.
Consult the [Product image selection documentation](https://docs.stackable.tech/home/nightly/concepts/product_image_selection) for details.
Variants