pub struct AirflowClusterDagProcessorsRoleConfigPodDisruptionBudget {
pub enabled: Option<bool>,
pub max_unavailable: Option<u16>,
}Expand description
This struct is used to configure:
- If PodDisruptionBudgets are created by the operator
- The allowed number of Pods to be unavailable (
maxUnavailable)
Learn more in the [allowed Pod disruptions documentation](https://docs.stackable.tech/home/nightly/concepts/operations/pod_disruptions).
Fields
enabled: Option<bool>Whether a PodDisruptionBudget should be written out for this role. Disabling this enables you to specify your own - custom - one. Defaults to true.
The number of Pods that are allowed to be down because of voluntary disruptions. If you don’t explicitly set this, the operator will use a sane default based upon knowledge about the individual product.