pub struct AirflowClusterKubernetesExecutorsConfig {
pub affinity: Option<AirflowClusterKubernetesExecutorsConfigAffinity>,
pub graceful_shutdown_timeout: Option<String>,
pub logging: Option<AirflowClusterKubernetesExecutorsConfigLogging>,
pub resources: Option<AirflowClusterKubernetesExecutorsConfigResources>,
}Fields
affinity: Option<AirflowClusterKubernetesExecutorsConfigAffinity>These configuration settings control [Pod placement](https://docs.stackable.tech/home/nightly/concepts/operations/pod_placement).
graceful_shutdown_timeout: Option<String>Time period Pods have to gracefully shut down, e.g. 30m, 1h or 2d. Consult the operator documentation for details.
logging: Option<AirflowClusterKubernetesExecutorsConfigLogging>Logging configuration, learn more in the [logging concept documentation](https://docs.stackable.tech/home/nightly/concepts/logging).
resources: Option<AirflowClusterKubernetesExecutorsConfigResources>Resource usage is configured here, this includes CPU usage, memory usage and disk storage usage, if this role needs any.