pub struct AirflowClusterTriggerersConfigResourcesMemory {
pub limit: Option<String>,
pub runtime_limits: Option<AirflowClusterTriggerersConfigResourcesMemoryRuntimeLimits>,
}Fields
limit: Option<String>The maximum amount of memory that should be available to the Pod.
Specified as a byte [Quantity](https://kubernetes.io/docs/reference/kubernetes-api/common-definitions/quantity/),
which means these suffixes are supported: E, P, T, G, M, k.
You can also use the power-of-two equivalents: Ei, Pi, Ti, Gi, Mi, Ki.
For example, the following represent roughly the same value:
128974848, 129e6, 129M, 128974848000m, 123Mi
runtime_limits: Option<AirflowClusterTriggerersConfigResourcesMemoryRuntimeLimits>Additional options that can be specified.