AirflowClusterWebservers

Struct AirflowClusterWebservers 

pub struct AirflowClusterWebservers {
    pub cli_overrides: Option<BTreeMap<String, String>>,
    pub config: Option<AirflowClusterWebserversConfig>,
    pub config_overrides: Option<BTreeMap<String, BTreeMap<String, String>>>,
    pub env_overrides: Option<BTreeMap<String, String>>,
    pub pod_overrides: Option<BTreeMap<String, Value>>,
    pub role_config: Option<AirflowClusterWebserversRoleConfig>,
    pub role_groups: BTreeMap<String, AirflowClusterWebserversRoleGroups>,
}
The webservers role provides the main UI for user interaction.

Fields

cli_overrides: Option<BTreeMap<String, String>>config: Option<AirflowClusterWebserversConfig>config_overrides: Option<BTreeMap<String, BTreeMap<String, String>>>

The configOverrides can be used to configure properties in product config files that are not exposed in the CRD. Read the [config overrides documentation](https://docs.stackable.tech/home/nightly/concepts/overrides#config-overrides) and consult the operator specific usage guide documentation for details on the available config files and settings for the specific product.

env_overrides: Option<BTreeMap<String, String>>

envOverrides configure environment variables to be set in the Pods. It is a map from strings to strings - environment variables and the value to set. Read the [environment variable overrides documentation](https://docs.stackable.tech/home/nightly/concepts/overrides#env-overrides) for more information and consult the operator specific usage guide to find out about the product specific environment variables that are available.

pod_overrides: Option<BTreeMap<String, Value>>

In the podOverrides property you can define a [PodTemplateSpec](https://kubernetes.io/docs/reference/generated/kubernetes-api/v1.27/#podtemplatespec-v1-core) to override any property that can be set on a Kubernetes Pod. Read the [Pod overrides documentation](https://docs.stackable.tech/home/nightly/concepts/overrides#pod-overrides) for more information.

role_config: Option<AirflowClusterWebserversRoleConfig>

This is a product-agnostic RoleConfig, which is sufficient for most of the products.

role_groups: BTreeMap<String, AirflowClusterWebserversRoleGroups>